import {
  Http, Metadata,
} from '@zeedhi/core';
import {
  DialogService, Form, LoadingService, Modal, ModalService, Select, TextInput, Time,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Fm070000ParametrosSensorController {
  public basicModal!: Modal;

  public async exibirModal() {
    this.basicModal = await ModalService.createFromJson('/fm_070_000_parametros_sensor/modal/fm_070_001_inserir_parametros_sensor', true);
    this.basicModal.show();
  }

  public fecharModal() {
    this.basicModal.hide();
    this.basicModal?.destroy();
  }

  public async abrirModoInsercao() {
    await this.exibirModal();
    /* const prodFaturamento = Metadata.getInstance<Select>('prod-faturamento');
    prodFaturamento.isVisible = true;
    prodFaturamento.addValidation('required', {});
    Metadata.getInstance<Select>('idativo').disabled = true;
    */
  }

  public async abrirModoEdicao({ row }: any): Promise<void> {
    await this.exibirModal();
    const cliente = Metadata.getInstance<Select>('cliente');
    const tipoSensor = Metadata.getInstance<Select>('tipo-sensor');
    const localSensor = Metadata.getInstance<Select>('local-sensor');
    const idMacAddress = Metadata.getInstance<Select>('mac-address');
    const idSensor = Metadata.getInstance<Select>('id-sensor');
    const idModoDistancia = Metadata.getInstance<Select>('IDMODODISTANCIA');

    Metadata.getInstance<TextInput>('cod-sensor').value = row.NRPARAMLEITCONTPESSOAS;
    Metadata.getInstance<TextInput>('descricao-sensor').value = row.DSSENSOR;
    Metadata.getInstance<TextInput>('NRQTPESSOASALERT').value = row.NRQTPESSOASALERT;
    Metadata.getInstance<TextInput>('VRDISTANCIAMINLEIT').value = row.VRDISTANCIAMINLEIT;
    Metadata.getInstance<TextInput>('VRDISTANCIAMAXLEIT').value = row.VRDISTANCIAMAXLEIT;
    Metadata.getInstance<TextInput>('VRDISTANCIAMEDLEIT').value = row.VRDISTANCIAMEDLEIT;
    Metadata.getInstance<TextInput>('QTMATRIZLEITURA').value = row.QTMATRIZLEITURA;
    Metadata.getInstance<TextInput>('QTTEMPRECONHECIMENTO').value = row.QTTEMPRECONHECIMENTO;
    Metadata.getInstance<TextInput>('HRINICIODIA').value = row.HRINICIODIA;
    Metadata.getInstance<TextInput>('HRFINALDIA').value = row.HRFINALDIA;
    Metadata.getInstance<TextInput>('QTTEMPOREPETLEIT').value = row.QTTEMPOREPETLEIT;
    Metadata.getInstance<TextInput>('IPATUALIZASENSORES').value = row.IPATUALIZASENSORES;
    /* prodFaturamento.isVisible = false;
    prodFaturamento.clearValidations();
    ativo.value = row.IDATIVO; */
    cliente.value = row.CDCLIENTE;
    tipoSensor.value = row.IDTIPOSENSOR;
    localSensor.value = row.NRLOCALCLIENTE;
    idMacAddress.value = row.IDMACDEVICE;
    idSensor.value = row.IDSENSOR;
    idModoDistancia.value = row.IDMODODISTANCIA;
    // ativo.disabled = false;
  }

  public ativaCamposSensorDistancia({ component }: any) {
    const distanciaMinima = Metadata.getInstance<TextInput>('VRDISTANCIAMINLEIT');
    const distanciaMaxima = Metadata.getInstance<TextInput>('VRDISTANCIAMAXLEIT');
    const distanciaLimite = Metadata.getInstance<TextInput>('VRDISTANCIAMEDLEIT');
    const numeroLinhasMatriz = Metadata.getInstance<TextInput>('QTMATRIZLEITURA');
    const tempoLeitura = Metadata.getInstance<TextInput>('QTTEMPRECONHECIMENTO');
    const modoDistancia = Metadata.getInstance<Select>('IDMODODISTANCIA');
    if (component.value === '2 ') {
      distanciaMinima.disabled = false;
      distanciaMaxima.disabled = false;
      distanciaLimite.disabled = false;
      numeroLinhasMatriz.disabled = false;
      tempoLeitura.disabled = false;
      modoDistancia.disabled = false;
    } else {
      distanciaMinima.disabled = true;
      distanciaMaxima.disabled = true;
      distanciaLimite.disabled = true;
      numeroLinhasMatriz.disabled = true;
      tempoLeitura.disabled = true;
      modoDistancia.disabled = true;
    }
  }

  public clickButtonToExpand({ component }: any) {
    const form = Metadata.getInstance<Form>(`formTarefas_${component.name}`);
    form.isVisible = !form.isVisible;
    component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
  }

  public inserirSensor() {
    const form = Metadata.getInstance<Form>('form').validate();
    const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-sensor');

    if (form) {
      LoadingService.show();
      Http.post('/inserirSensor', {
        NRPARAMLEITCONTPESSOAS: Metadata.getInstance<TextInput>('cod-sensor').value,
        CDCLIENTE: Metadata.getInstance<Select>('cliente').value,
        IDTIPOSENSOR: Metadata.getInstance<Select>('tipo-sensor').value,
        IDMACDEVICE: Metadata.getInstance<Select>('mac-address').value,
        IDSENSOR: Metadata.getInstance<Select>('id-sensor').value,
        NRQTPESSOASALERT: Metadata.getInstance<TextInput>('NRQTPESSOASALERT').value,
        VRDISTANCIAMINLEIT: Metadata.getInstance<TextInput>('VRDISTANCIAMINLEIT').value,
        VRDISTANCIAMAXLEIT: Metadata.getInstance<TextInput>('VRDISTANCIAMAXLEIT').value,
        VRDISTANCIAMEDLEIT: Metadata.getInstance<TextInput>('VRDISTANCIAMEDLEIT').value,
        QTMATRIZLEITURA: Metadata.getInstance<TextInput>('QTMATRIZLEITURA').value,
        QTTEMPRECONHECIMENTO: Metadata.getInstance<TextInput>('QTTEMPRECONHECIMENTO').value,
        IDMODODISTANCIA: Metadata.getInstance<Select>('IDMODODISTANCIA').value,
        QTTEMPOREPETLEIT: Metadata.getInstance<TextInput>('QTTEMPOREPETLEIT').value,
        HRINICIODIA: Metadata.getInstance<Time>('HRINICIODIA').value,
        HRFINALDIA: Metadata.getInstance<Time>('HRFINALDIA').value,
        IDATIVO: 'S',
        NRLOCALCLIENTE: Metadata.getInstance<Select>('local-sensor').value,
        DSSENSOR: Metadata.getInstance<TextInput>('descricao-sensor').value,
        IDMONITORAMENTO: 'N',
        NRSEQLEITURA: null,
        QTPESSOAS: 0,
        IPATUALIZASENSORES: Metadata.getInstance<TextInput>('IPATUALIZASENSORES').value,
      }).then(() => {
        this.fecharModal();
        grid.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        if (error.response.data.error === 'SENSOR JÁ EXISTE') {
          Utilities.showErrorMessage('Não foi possível atualizar este Serviço pois ele está ativo');
        } else {
          Utilities.showErrorMessage(error);
        }
      }).finally(() => {
        LoadingService.hide();
      });
    } else {
      Utilities.showErrorMessage('Preencha todos os campos obrigatórios (*)');
    }
  }

  public dialogDeletarParametrosSensor({ event }: any) {
    event.preventDefault();
    DialogService.show({
      name: 'dialog-deletar',
      type: 'warning',
      title: 'Atenção',
      text: 'Todos os dados deste(s) sensor(s) serão perdidos. Deseja continuar?',
      buttons: [
        {
          name: 'NAO',
          component: 'ZdButton',
          label: 'Não',
          outline: true,
          events: {
            click: () => {
              DialogService.hide();
            },
          },
        },
        {
          name: 'sim',
          component: 'ZdButton',
          label: 'Sim',
          events: {
            click: () => {
              this.deletarParametrosSensor();
              DialogService.hide();
            },
          },
        },
      ],
    });
  }

  public async deletarParametrosSensor() {
    const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-sensor');
    LoadingService.show();
    try {
      await Http.post('/deletarParametrosSensor', grid.selectedRows);
      await grid.cancelEditedRows();
      await grid.reload();
      Utilities.showSuccessMessage();
    } catch (e) {
      Utilities.showErrorMessage(e);
    }
    LoadingService.hide();
  }
}
